﻿using Prism.Commands;
using Prism.Mvvm;
using Syncfusion.UI.Xaml.Grid;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Input;
using WpfTestingSample.Model;

namespace WpfTestingSample
{
    class ViewModel : BindableBase, INotifyPropertyChanged
    {
        private bool isHidden = true;
        public bool IsHidden
        {
            get { return isHidden; }
            set
            {
                isHidden = value;
                OnPropertyChanged("IsHidden");
            }
        }
        EmployeeDetails emp = new EmployeeDetails();

        #region Constructor

        public ViewModel()
        {
            SetSfGridColumns();
            this.GDCSource = emp;
            NavigateCommand = new DelegateCommand(ClickedMethod);
        }

        private Columns sfGridColumns;
        public Columns SfGridColumns
        {
            get { return sfGridColumns; }
            set { this.sfGridColumns = value; }
        }

        /// <summary>
        /// To generate the columns for SfDataGrid
        /// </summary>
        protected void SetSfGridColumns()
        {
            this.sfGridColumns = new Columns();
            sfGridColumns.Add(new GridTextColumn() { MappingName = "EmployeeName" });
            sfGridColumns.Add(new GridNumericColumn() { MappingName = "EmployeeAge", NumberDecimalDigits = 0 });
            sfGridColumns.Add(new GridNumericColumn() { MappingName = "EmployeeSalary" });
            sfGridColumns.Add(new GridNumericColumn() { MappingName = "ExperienceInMonth", NumberDecimalDigits = 0 });
        }

        private void ClickedMethod()
        {
            //Do your actions here.
        }

        #endregion

        private ObservableCollection<BusinessObjects> gdcsource;
        public ObservableCollection<BusinessObjects> GDCSource
        {
            get
            {
                return gdcsource;
            }
            set
            {
                gdcsource = value;
                OnPropertyChanged("GDCSource");
            }
        }

        public ICommand NavigateCommand { get; private set; }


        #region INotifyPropertyChanged Members

        public event PropertyChangedEventHandler PropertyChanged;

        private void OnPropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
        }

        #endregion


    }

    #region GDCSource DataSource
    class EmployeeDetails : ObservableCollection<BusinessObjects>
    {
        Random rand = new Random();
        public EmployeeDetails()
        {
            PopulateCollection();
        }
        string[] EmployeeAreas = { "USA", "UK", "UAE", "India" };
        string[] EmployeeName = { "Peter", "Mart", "James", "Oliver", "Robert", "Suji", "Mahesh", "Ruby" };
        private void PopulateCollection()
        {
            this.Clear();
            Random r = new Random();
            for (int i = 0; i < 10; i++)
            {
                BusinessObjects b = new BusinessObjects();
                b.EmployeeId = 1000 + i;
                b.EmployeeSalary = r.Next(10000, 50000);
                b.ExperienceInMonth = r.Next(1, 20);
                b.EmployeeDetails = GetEmployeeDetails();
                this.Add(b);
            }
        }

        private List<Employee> GetEmployeeDetails()
        {
            List<Employee> empDetails = new List<Employee>();
            for(int i= 0; i<=2;i++)
            {
                Employee emp = new Employee()
                {
                    EmployeeName = EmployeeName[rand.Next(0, 8)],
                    EmployeeArea = EmployeeAreas[rand.Next(0, 3)],
                    EmployeeAge = rand.Next(25, 40)
                };
                empDetails.Add(emp);
            }
            return empDetails;
        }
    }

    #endregion
}
